==> webgen-0.2.tgz: webgen-0.2/prj.php <==
<?php
 /***********************************************************
  䴩ͺ\
  ΨӳBz@M檺{
  submit1=w   w\
  process=d   dߥ\
  process=[峹 showXs峹s榡
  process=sW   usWƮw\
  process=R   R峹\
  process=ק   iJק峹sҦ
  process=update uק峹
 ************************************************************/
 require("config.php");
 require("dbconfig.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="prj.php";
  //TableXSOѼ
 $tabout="border=1";
  //d߳浧ƪY
  //C@
 $PGNUM=20;
 // Primary Key	
 $PKEY="aid";
 $RETADD="maintain.html";
 /******N_ର@*****/
 function nl22br($txt)
 {
    $ntxt="";
    $stok=strtok($txt,"\n");
    while (!($stok === FALSE))
    {
	$stok=trim($stok);
	if (strlen($stok)) $ntxt=$ntxt."\n".$stok;
	else $ntxt=$ntxt."<br>\n";
	$stok=strtok("\n");
    }
    return(substr($ntxt,1));//hh\n
 }
 require("auth.php");
 $DAYTIME=date("Y~mdH:i:s");
 //show insert and search form
 if (strcmp($submit1,"w")==0) 
 {
  //TJM[ӵqշ_Ϊ
    $txt=nl22br($txt);
    $abst=nl22br($abst);
	 /*****	XnͪM *******/
   $QUERY="select ptab,pname,ctlfile,target from main where ptab = '$ptab'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow!=1){
        echo "MƬdߧ $numrow ơAO $QUERY !";
        exit;
   }
   	$PARAW=db_fetch_row($result,0); //Ū@M峹O
	$PARAW[2]=trim($PARAW[2]);
        $CONF=$CDIR.$PARAW[2].".cfg";
	/* $fn1=$DESTDIR.trim($ARAW[0])."1234.html"; remove by tjm for test */
	
	  if (file_exists($CONF))
 	  	$OUT1=join( "", file( $CONF ) );
	  else
	  {
		echo "ɮ $CONF sbI<br>\n";
	  }
	
	  /****** ഫ *****/
	  $OUT1=str_replace("%title%",$title,$OUT1); //title
	  $OUT1=str_replace("%author%",$author,$OUT1); //author
	  $OUT1=str_replace("%pubtime%",$pubtime,$OUT1); //ptime
	  $OUT1=str_replace("%abst%",$abst,$OUT1); //abst
	  $OUT1=str_replace("%txt%",$txt,$OUT1); //txt
	  $OUT1=str_replace("%email%",$email,$OUT1); //email
	  $OUT1=str_replace("%username%",$PHP_AUTH_USER,$OUT1); //usernam
	  $ofn1=trim($ARAW[0])."567.html";
	  $OUT1=str_replace("%prev%",$ofn1,$OUT1); //previous file
	  echo $OUT1;
	 exit;
 }
 
 if ((strcmp($process,"[峹")==0)||(strcmp($process,"d")==0)) 
 {
   $QUERY="select ptab,pname from main where ptab='$key'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
	echo "MƬd߿~AO $QUERY !";
	exit;
   }
   $numrow=db_NumRows($result);  
   if ($numrow>1){
	echo "MƬdߧ $numrow ơAO $QUERY !";
	exit;
   }
   if ($numrow==0){
	echo "MƬdߧ䤣ơAO $QUERY !";
	exit;
   }
   $ARAW=db_fetch_row($result,0); //Ū@O
   /****}榡 ******/
   if (strcmp($process,"[峹")==0)
   	$OUT=join( "", file( "inprj.cfg" ) );
   else
   	$OUT=join( "", file( "search.cfg" ) );
   $OUT=str_replace("%CNAME",$ARAW[1],$OUT);
   $OUT=str_replace("%PRJ","<input type=\"hidden\" name=ptab value=\"$key\">",$OUT);
   $DAYTIME=date("Y.m.d");
   $OUT=str_replace("%TIME",$DAYTIME,$OUT);
   echo $OUT;
   exit;
 }
 if (get_magic_quotes_gpc()==0)
  {
	$title=addslashes($title);
	$author=addslashes($author);
	$abst=addslashes($abst);
	$txt=addslashes($txt);
	$email=addslashes($email);
	
  }
  //TJM[ӵqշ_Ϊ
    $txt=nl22br($txt);
    $abst=nl22br($abst);
  //INSERTOAoӫOdn|yۮeD
  $INSERT="insert into $ptab values (coalesce(max($ptab.aid)+1,1), '$title','$author','$pubtime','$abst','$txt','$email','$PHP_AUTH_USER','$REMOTE_ADDR','$DAYTIME');"; 
  //DELETEO
 $LIMIT=stripslashes($LIMIT);
 $DELETE="delete from $ptab  where ".$LIMIT;
 if (strcmp($process,"sW")==0) // insert
 {
   /******** ˬdOO ****/
   $result=db_exec($db_conn,$INSERT);
   if (!$result){
	echo "ƷsW~AO $INSERT !";
	exit;
   }
	echo "<a href=\"$RETADD\">J\IB}I</a>\n";
 	exit;
 }
 /******** Update ****************/
  $UPDATE="update $ptab set title='$title',author='$author',pubtime='$pubtime', abst='$abst', txt='$txt',email='$email',username='$PHP_AUTH_USER',ip='$REMOTE_ADDR',modtime='$DAYTIME' where ".$LIMIT;
 if (strcmp($process,"update")==0) // update
 {
   $result=db_exec($db_conn,$UPDATE);
   if (!$result){
        echo "ƷsW~AO $UPDATE !";
        exit;
   }
        echo "<a href=\"$RETADD\">s\IB}I</a>\n";
        exit;
 }

 /*****  R ********/
 if (strcmp($process,"R")==0) //DELETE 
 {
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !";
	exit;
   }
	echo "<a href=\"$RETADD\">R\IB}I</a>\n";
        exit;
 }
 /*****  ק ********/
 $EDIT="select title,author,email,pubtime,abst,txt from $ptab where ".$LIMIT;
 if (strcmp($process,"ק")==0) //EDIT 
 {
   $result=db_exec($db_conn,$EDIT);
   if (!$result){
	echo "ƭק~AO $EDIT !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   // add by tjm to replace KnPe
   $ARAW[4]=str_replace("<br>","",$ARAW[4]);
   $ARAW[5]=str_replace("<br>","",$ARAW[5]);
   /****} ******/
   $fcfg=fopen("editprj.cfg","r");
   $cnt=0;
   $PAT="%DATA";
   while (!feof($fcfg)) 
      {
         $temp=fgets($fcfg,256);
 	 if (strstr($temp,$PAT))
         {
		$temp=str_replace($PAT,$ARAW[$cnt],$temp);
		$cnt=$cnt+1;
	 } elseif (strstr($temp,"%LIMIT"))
	 {
		$temp=str_replace("%LIMIT","<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">",$temp);
	 }
	 elseif (strstr($temp,"%PRJ"))
	 {
		$temp=str_replace("%PRJ","<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">",$temp);
	 }
	 echo $temp;
      }
   fclose($fcfg);
        exit;
 }
?>

==> webgen-0.3.tgz: webgen-0.3/prj.php <==
<?php
 /***********************************************************
  䴩ͺ\
  ΨӳBz@M檺{
  submit1=w   w\
  process=d   dߥ\
  process=[峹 showXs峹s榡
  process=sW   usWƮw\
  process=R   R峹\
  process=ק   iJק峹sҦ
  process=update uק峹
 ************************************************************/
 require("config.php");
 require("dbconfig.php");
 /**** @ܼ ********/
  //W
 $PROGNAME="prj.php";
  //TableXSOѼ
 $tabout="border=1";
  //d߳浧ƪY
  //C@
 $PGNUM=20;
 // Primary Key	
 $PKEY="aid";
 $RETADD="index.html";
 /******N_ର@*****/
 function nl22br($txt)
 {
    $ntxt="";
    $stok=strtok($txt,"\n");
    while (!($stok === FALSE))
    {
	$stok=trim($stok);
	if (strlen($stok)) $ntxt=$ntxt."\n".$stok;
	else $ntxt=$ntxt."<br>\n";
	$stok=strtok("\n");
    }
    return(substr($ntxt,1));//hh\n
 }
 require("auth.php");
 $DAYTIME=date("Y~mdH:i:s");
 //show insert and search form
 if (strcmp($submit1,"w")==0) 
 {
  //TJM[ӵqշ_Ϊ
    $txt=nl22br($txt);
    $abst=nl22br($abst);
	 /*****	XnͪM *******/
   $QUERY="select ptab,pname,ctlfile,target from main where ptab = '$ptab'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow!=1){
        echo "MƬdߧ $numrow ơAO $QUERY !";
        exit;
   }
   	$PARAW=db_fetch_row($result,0); //Ū@M峹O
	$PARAW[2]=trim($PARAW[2]);
        $CONF=$CDIR.$PARAW[2].".cfg";
	/* $fn1=$DESTDIR.trim($ARAW[0])."1234.html"; remove by tjm for test */
	  if (file_exists($CONF)&&(!is_link($CONF)))
 	  	$OUT1=join( "", file( $CONF ) );
	  else
	  {
		echo "ɮ $CONF sbI<br>\n";
	  }
	
	  /****** ഫ *****/
	  $OUT1=str_replace("%title%",$title,$OUT1); //title
	  $OUT1=str_replace("%author%",$author,$OUT1); //author
	  $OUT1=str_replace("%pubtime%",$pubtime,$OUT1); //ptime
	  $OUT1=str_replace("%abst%",$abst,$OUT1); //abst
	  $OUT1=str_replace("%txt%",$txt,$OUT1); //txt
	  $OUT1=str_replace("%email%",$email,$OUT1); //email
	  $OUT1=str_replace("%username%",$PHP_AUTH_USER,$OUT1); //usernam
	  $ofn1=trim($ARAW[0])."567.html";
	  $OUT1=str_replace("%prev%",$ofn1,$OUT1); //previous file
	  echo $OUT1;
	 exit;
 }
 
 if ((strcmp($process,"[峹")==0)||(strcmp($process,"d")==0)) 
 {
   $QUERY="select ptab,pname from main where ptab='$key'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
	echo "MƬd߿~AO $QUERY !";
	exit;
   }
   $numrow=db_NumRows($result);  
   if ($numrow>1){
	echo "MƬdߧ $numrow ơAO $QUERY !";
	exit;
   }
   if ($numrow==0){
	echo "MƬdߧ䤣ơAO $QUERY !";
	exit;
   }
   $ARAW=db_fetch_row($result,0); //Ū@O
   /****}榡 ******/
   if (strcmp($process,"[峹")==0)
   	$OUT=join( "", file( "inprj.cfg" ) );
   else
   	$OUT=join( "", file( "search.cfg" ) );
   $OUT=str_replace("%CNAME",$ARAW[1],$OUT);
   $OUT=str_replace("%PRJ","<input type=\"hidden\" name=ptab value=\"$key\">",$OUT);
   $DAYTIME=date("Y.m.d");
   $OUT=str_replace("%TIME",$DAYTIME,$OUT);
   echo $OUT;
   exit;
 }
 if (get_magic_quotes_gpc()==0)
  {
	$title=addslashes($title);
	$author=addslashes($author);
	$abst=addslashes($abst);
	$txt=addslashes($txt);
	$email=addslashes($email);
	
  }
  //TJM[ӵqշ_Ϊ
    $txt=nl22br($txt);
    $abst=nl22br($abst);
  //INSERTOAoӫOdn|yۮeD
  $INSERT="insert into $ptab values (coalesce(max($ptab.aid)+1,1), '$title','$author','$pubtime','$abst','$txt','$email','$PHP_AUTH_USER','$REMOTE_ADDR','$DAYTIME');"; 
  //DELETEO
 $LIMIT=stripslashes($LIMIT);
 $DELETE="delete from $ptab  where ".$LIMIT;
 if (strcmp($process,"sW")==0) // insert
 {
   /******** ˬdOO ****/
   $result=db_exec($db_conn,$INSERT);
   if (!$result){
	echo "ƷsW~AO $INSERT !";
	exit;
   }
	echo "<a href=\"$RETADD\">J\IB}I</a>\n";
 	exit;
 }
 /******** Update ****************/
  $UPDATE="update $ptab set title='$title',author='$author',pubtime='$pubtime', abst='$abst', txt='$txt',email='$email',username='$PHP_AUTH_USER',ip='$REMOTE_ADDR',modtime='$DAYTIME' where ".$LIMIT;
 if (strcmp($process,"update")==0) // update
 {
   $result=db_exec($db_conn,$UPDATE);
   if (!$result){
        echo "ƷsW~AO $UPDATE !";
        exit;
   }
        echo "<a href=\"$RETADD\">s\IB}I</a>\n";
        exit;
 }

 /*****  R ********/
 if (strcmp($process,"R")==0) //DELETE 
 {
   $result=db_exec($db_conn,$DELETE);
   if (!$result){
	echo "ƧR~AO $DELETE !";
	exit;
   }
	echo "<a href=\"$RETADD\">R\IB}I</a>\n";
        exit;
 }
 /*****  ק ********/
 $EDIT="select title,author,email,pubtime,abst,txt from $ptab where ".$LIMIT;
 if (strcmp($process,"ק")==0) //EDIT 
 {
   $result=db_exec($db_conn,$EDIT);
   if (!$result){
	echo "ƭק~AO $EDIT !";
	exit;
   }
   $numrow=db_NumRows($result);  
   $ARAW=db_fetch_row($result,0); //Ū@O
   // add by tjm to replace KnPe
   $ARAW[4]=str_replace("<br>","",$ARAW[4]);
   $ARAW[5]=str_replace("<br>","",$ARAW[5]);
   /****} ******/
   $fcfg=fopen("editprj.cfg","r");
   $cnt=0;
   $PAT="%DATA";
   while (!feof($fcfg)) 
      {
         $temp=fgets($fcfg,256);
 	 if (strstr($temp,$PAT))
         {
		$temp=str_replace($PAT,$ARAW[$cnt],$temp);
		$cnt=$cnt+1;
	 } elseif (strstr($temp,"%LIMIT"))
	 {
		$temp=str_replace("%LIMIT","<input type=\"hidden\" name=\"LIMIT\" value=\"$LIMIT\">",$temp);
	 }
	 elseif (strstr($temp,"%PRJ"))
	 {
		$temp=str_replace("%PRJ","<input type=\"hidden\" name=\"ptab\" value=\"$ptab\">",$temp);
	 }
	 echo $temp;
      }
   fclose($fcfg);
        exit;
 }
?>
